/*
Prepare data from DEAS 1996

Variables needed: 

- sex
- Children yes/no
- Number of biological children
- Educational level
- Birth date / Cohort
- Born in Germany
- where lived before reunification
- interview date
- weights


Sample information ( Engstler &  Lejeune 2014, Kurzbeschreibung DEAS 1996): 
- In Welle 1 (1996) beschränkte sich die Auswahl auf Personen mit deutscher Staatsangehörigkeit
- Grundgesamtheit: In Privathaushalten (nur Hauptwohnsitz) lebende Deutsche der Geburtsjahrgänge 1911-1956
- Stichprobe: Personenstichprobe aus 290 Gemeinden (Einwohner- meldeamtsregister); disproportionale Auswahl nach Region (Ost/West), Alter (40-54/55-69/70-85 Jahre) und Geschlecht
*/


use ${data_deas_1996}, clear

//  4.838
count

rename v1_11 sex 
gen birth = 1900 + v1_16

rename v11_39 nofchildren 

rename v16_56 geburtsort

gen numbiochild = 0 // number of reported biological children
foreach num of numlist 12/14 15 50/57 {
	replace numbiochild = numbiochild + 1 if v`num'_15 == 1
}
// Note: number of reported bio children may be biased towards zero since 
//       not specified missings in family relationship are treated as non-bio child.

// Living biological children (i.e. children who are still living or lived at least to 20)

gen numbiochildliv = 0 
foreach num of numlist 12/14 15 50/57 {
	replace numbiochildliv = numbiochildliv + 1 if v`num'_15 == 1 & (v`num'_18==1 | (v`num'_18==2 & (v`num'_32 - v`num'_16)>=20))
}

// ACHTUNG: Datenfehler in v4_11 => code .c bedeutet fachhochschulreife!!!
// siehe codebook
recode v4_11 (.c = 6)
recode v4_11 (1 9 = 1 "kein Abschluss") ///
		   (2 4 = 2 "HS" ) ///
		   (3 5 = 3 "RS")  ///
		   (6 7 = 4 "ABI") ///
		   (8 = 5 "sonstiges") ///
		   , gen(CASMIN_gen)

// Teil|fach|ar|bei|ter, der (DDR): angelernter Arbeiter 
// (ohne abgeschlossene Ausbildung).
// Teilfacharbeiter => keine Ausbildung, eher Lehrgang

// ACHTUNG: Datenfehler in v4_13 => code .c bedeutet Hochschulabschluss!!!
// siehe codebook
recode v4_13 (.c = 6) // now distribution is consistent with codebook

recode v4_13 (1 8 = 1 "keine BA") ///
		   (2 3 4 = 2 "BA") ///
		   (5 = 3 "FH") ///
		   (6 = 4 "Uni") ///
		   (7 = 5 "sonstiges") ///
		  , gen(CASMIN_voc)


// combine
gen CASMIN = -1
lab def CASMIN ///
9 "3b Hochschulabschluss" ///
8 "3a Fachhochschulabschluss" ///
7 "2c_voc Fachhochschulreife/Abitur und berufliche Ausbildung" ///
6 "2c_gen Fachhochschulreife/Abitur ohne berufliche Ausbildung" ///
5 "2a Mittlere Reife und berufliche Ausbildung" ///
4 "2b Mittlere Reife ohne berufliche Ausbildung" ///
3 "1c Hauptschulabschluss und berufliche Ausbildung" ///
2 "1b Hauptschulabschluss ohne berufliche Ausbildung" ///
1 "1a kein Abschluss" ///
.b "nicht bestimmbar" ///
, modify

lab val CASMIN CASMIN
replace CASMIN = 9 if CASMIN_voc == 4
replace CASMIN = 8 if CASMIN_voc == 3
replace CASMIN = 7 if CASMIN_voc == 2 & CASMIN_gen == 4
replace CASMIN = 6 if CASMIN_voc == 1 & CASMIN_gen == 4
replace CASMIN = 5 if CASMIN_voc == 2 & CASMIN_gen == 3
replace CASMIN = 4 if CASMIN_voc == 1 & CASMIN_gen == 3
replace CASMIN = 3 if CASMIN_voc == 2 & CASMIN_gen == 2
replace CASMIN = 2 if CASMIN_voc == 1 & CASMIN_gen == 2
replace CASMIN = 1 if CASMIN_voc == 1 & CASMIN_gen == 1
// special cases: 
// no school degree but BA => define as "HS mit BA"
replace CASMIN = 3 if CASMIN_gen==1 & CASMIN_voc==2 & CASMIN==-1
// other school degree and BA => define as "HS mit BA"
replace CASMIN = 3 if CASMIN_gen==5 & CASMIN_voc==2 & CASMIN==-1
/*
// "die Schule ohne Abschluss verlassen" & 
// "die Pflichtschule mit Abschluss beendet" => dito
replace CASMIN = 3 if inlist(x28,1,2) & CASMIN_voc==2 & CASMIN==-1
// "eine weiterführende Schule mit Abschluss beendet" => RS + BA
replace CASMIN = 5 if inlist(x28,3) & CASMIN_voc==2 & CASMIN==-1
// "weiß nicht / verweigert" => assign Hauptschule!
*/
replace CASMIN = 3 if mi(CASMIN_gen) & CASMIN_voc==2 & CASMIN==-1

/*
// keine BA & kein schulabschluss
replace CASMIN = 1 if x28==1 & CASMIN_voc==1 & CASMIN==-1
replace CASMIN = 2 if x28==2 & CASMIN_voc==1 & CASMIN==-1
replace CASMIN = 4 if x28==3 & CASMIN_voc==1 & CASMIN==-1

// sonstige Ausbildung (kodiere als keine Berufsausbildung)
replace CASMIN = 1 if x28==1 & x31==5 & CASMIN==-1
replace CASMIN = 2 if x28==2 & x31==5 & CASMIN==-1
replace CASMIN = 4 if x28==3 & x31==5 & CASMIN==-1
*/

replace CASMIN = 1 if CASMIN_gen == 1 & CASMIN_voc == 5 & CASMIN == -1
replace CASMIN = 2 if CASMIN_gen == 2 & CASMIN_voc == 5 & CASMIN == -1
replace CASMIN = 4 if CASMIN_gen == 3 & CASMIN_voc == 5 & CASMIN == -1
replace CASMIN = 6 if CASMIN_gen == 4 & CASMIN_voc == 5 & CASMIN == -1

// if ausbildung was skipped
replace CASMIN = 1 if CASMIN_gen == 1 & mi(CASMIN_voc) & CASMIN == -1
replace CASMIN = 2 if CASMIN_gen == 2 & mi(CASMIN_voc) & CASMIN == -1
replace CASMIN = 2 if CASMIN_gen == 2 & mi(CASMIN_voc) & CASMIN == -1
replace CASMIN = 4 if CASMIN_gen == 3 & mi(CASMIN_voc) & CASMIN == -1
replace CASMIN = 6 if CASMIN_gen == 4 & mi(CASMIN_voc) & CASMIN == -1

/*
replace CASMIN = 1 if x28==1 & x31==-1 & CASMIN==-1
replace CASMIN = 2 if x28==2 & x31==-1 & CASMIN==-1
replace CASMIN = 4 if x28==3 & x31==-1 & CASMIN==-1
replace CASMIN = 4 if inlist(x28,8,9) & x31==-1 & CASMIN==-1
*/
/*
// kein schulbesuch
replace CASMIN = 1 if x26==6 & CASMIN==-1
*/

// set rest to not determinable
replace CASMIN = .b if CASMIN==-1

drop CASMIN_*

lab var CASMIN "CASMIN-classes"
fre CASMIN

recode CASMIN (1 2 4 = 0 "low") /// no degree, hauptschule ohne BA, realschule ohne BA
		   (3 = 1 "lower voc") /// hauptschule mit BA
		   (5 =2 "medium voc") /// realschule mit BA
		   (6 7 = 3 "high voc") /// abitur +/- BA
		   (8 9  = 4 "university") /// tertiary, university
		   , gen(E)
// collapse high voc and university
capt drop E
recode CASMIN (1 2 4 = 0 "low") /// no degree, hauptschule ohne BA, realschule ohne BA
		   (3 = 1 "lower voc") /// hauptschule mit BA
		   (5 =2 "medium voc") /// realschule mit BA
		   (6 7 8 9 = 3 "high voc/university") /// abitur +/- BA, tertiary, university
		   , gen(E)	

recode birth 	(1914/1925.9 = 1 "1914-1926)") ///
			    (1926/1935.9 = 2 "1926-1936)") /// 
				(1936/1944.9 = 3 "1936-1945)") ///
				(1945/1960 = 4 "1945-1960") ///
				(else = .), gen(Chrt)		  

// collapse cohort categories
recode Chrt (1 2 = 1) (3 4 = 2),  gen(Chrt2) 

// usual residence last 40 years
rename v16_57 usualres40years 		   

keep fallnum stich gew_m2 nat_ewo_96 intmonat intjahr gew_m2 westost_96 bland_96 alter_96 sex E CASMIN ///
		birth Chrt Chrt2 nofchildren numbiochild numbiochildliv geburtsort	usualres40years	 isced_96
		
gen DEAS = 1996

save "${tempDir}/00_DEAS-1996.dta", replace		
