
* load original SUF data file
use "${data_deas_2011}", clear

rename gc1 sex
rename gc2_3 birth // view cases grouped to 1916, negligible
* item for number of children
rename gc300 nofchildren // own children or children who grew up with respondent
// up to child 8 is asked
gen numbiochild = 0 // number of reported biological children
foreach num of numlist 1/8 {
	replace numbiochild = numbiochild + 1 if inlist(gc303`num',1,2) | gc303a`num'==2 | gc303b`num' == 2 
}

// The original scientific use file contains coarsed and categorized dates for birth 
// of children and grandchildren for reasons of disclosure control. 
// This could blur even flaw our investigation of timing to grandparenthood. 
// For the purpose of our study, we obtained from the data center of the DZA 
// the original not manipulated date of birth variables. 

// Note: variable "fallnum" is the person identifier. 


// Replace not-anonymized birth dates. 
* 1) load add-on data (original birth dates)
preserve 
	use "${data_deas_2011_exact_birthdates}", clear
	renvars gc3041-gc3048, pref(EXACT_)
	tempfile exact
	save `exact'
restore
* 2) merge add-on data
merge 1:1 fallnum  using `exact', nogen


* 3) replace anonymized birth date data with exact data
* (child 1-4)
foreach var of varlist gc3041 gc3042 gc3043 gc3044 {
	order EXACT_`var', before(`var') 
	rename `var'  __`var' 
	rename EXACT_`var' `var'
}
* (child 5-8)
foreach num of numlist 5/8 {
	rename EXACT_gc304`num' gc304`num'
	order gc304`num', before(gc304`num'kat)
	drop gc304`num'kat
}
drop __*
// we do not have the exact death date for children
// take the middle value from the categories
foreach num of numlist 1/8 {
	gen gc315`num' = gc315`num'kat
	recode gc315`num' (1 = 1945) (2 = 1955) (3 = 1965) (4 = 1975) (5 = 1985) (6 = 1995) (7 = 2006) 
}

// Note: number of reported bio children may be biased towards zero since 
//       not specified missings in family relationship are treated as non-bio child.

// Living biological children (i.e. children who are still living or lived at least to 20)
gen numbiochildliv = 0 
foreach num of numlist 1/8 {
	replace numbiochildliv = numbiochildliv + 1 if (inlist(gc303`num',1,2) | gc303a`num'==2 | gc303b`num' == 2 ) /// bio child
							 & (gc304a`num'==1 | (gc304a`num'==2 & (gc315`num' - gc304`num')>=20))
}
keep fallnum intmonat intjahr gewint2011 part_96 part_02 part_08 stich sex alter_11 migrat_11 westost_11 birth nofchildren numbiochild numbiochildliv  ///
		birth isced_11

gen DEAS = 2011
/*-----------------------------------------
  Save data
-----------------------------------------*/
save "${tempDir}/00_DEAS-2011.dta", replace
