/*
 Extended analyses
 
 Analyses could be elaborated further by  
 - studying trends over time
 - additionally the role of assortative mating
 - studying Ed rep using more differentiated educational categories
*/

// SOCIAL REPRODUCTION RATE
capt program drop prospective_srr
program define prospective_srr, eclass
	syntax [if] // the if statement is very important 
	// preserve
	quiet {
		tempvar pr prcf s scf c
		
		logit cabi i.parabi c.F c.data [pw=sw] `if' // 
		est store ret 
		
		local N = `e(N)'
		
		// setting data to .5 (average dataset) 
		rename data _data 
		gen data = .5 `if'

		// predict child's probability of having abi=1
		predict `pr' `if'
		
		// 
		tempvar pr0 pr0cf s0 s0cf // child's probability of having not abi=1
		gen `pr0' = 1-`pr' `if'
		
		preserve 
			keep `if'
			collapse `pr' [aw=sw] , by(parabi)
			drop parabi
			mkmat `pr' , mat(p)
		restore 
		
		gen `c' = (1-z)

		// children?
		preserve 
			keep `if'
			collapse `c' [aw=sw*fsw*cw] , by(parabi)
			drop parabi
			mkmat `c' , mat(child)
		restore 
		
		// f | f > 0
		preserve 
			keep `if'
			collapse F [aw=sw*fsw] , by(parabi)
			drop parabi
			mkmat F , mat(f)
		restore 

		mat cfr = (child[1,1]*f[1,1]) \ (child[2,1]*f[2,1])
		
		// predict counterfactuals probability 
		rename parabi _parabi 
		gen parabi = _parabi == 0 `if'
		predict `prcf' `if'
		
		// not abi
		gen `pr0cf' = 1-`prcf' `if'
		
		drop parabi 
		rename _parabi parabi

		gen `s' = F*`pr'  `if'
		gen `scf' = F*`prcf'  `if'

		// not abi
		gen `s0' = F*`pr0'  `if'
		gen `s0cf' = F*`pr0cf'  `if'
		
		preserve 
			keep `if'
			collapse `s' `scf' [aw=sw*fsw*cw] , by(parabi)
			// li, noobs clean
			mkmat `s' `scf', mat(c) rownames(parabi)
		// mat li c
		restore
		
		mat r = (c[1,1]*child[1,1], c[1,2]*child[1,1]) \ (c[2,1]*child[2,1], c[2,2]*child[2,1])

		// no abi
		preserve 
			keep `if'
			collapse `s0' `s0cf' [aw=sw*fsw*cw] , by(parabi)
			// li, noobs clean
			mkmat `s0' `s0cf', mat(c0) rownames(parabi)
		// mat li c
		restore
		
		mat r0 = (c0[1,1]*child[1,1], c0[1,2]*child[1,1]) \ (c0[2,1]*child[2,1], c0[2,2]*child[2,1])

		
		
		local sr00 = r[1,1]
		local sr01 = r[1,2]
		local sr10 = r[2,2]
		local sr11 = r[2,1 ]
		
		// not abi
		local sr000 = r0[1,1]
		local sr001 = r0[1,2]
		local sr010 = r0[2,2]
		local sr011 = r0[2,1]
		
		// total effect 
		local te =  r[2,1] - r[1,1]

		// fertility part 
		local fe =  0.5*(r[2,1] - r[1,2] + r[2,2] - r[1,1])

		// IEO part 
		local ieo =  0.5*(r[2,1] + r[1,2] - r[2,2]  - r[1,1])

		// fertility %
		local fe_rel = 0.5*(r[2,1] - r[1,2] + r[2,2] - r[1,1]) / (r[2,1] - r[1,1]) 

		// not abi
		// total effect 
		local te0 =  r0[2,1] - r0[1,1]

		// fertility part 
		local fe0 =  0.5*(r0[2,1] - r0[1,2] + r0[2,2] - r0[1,1])

		// IEO part 
		local ieo0 =  0.5*(r0[2,1] + r0[1,2] - r0[2,2]  - r0[1,1])

		// fertility %
		local fe_rel0 = 0.5*(r0[2,1] - r0[1,2] + r0[2,2] - r0[1,1]) / (r0[2,1] - r0[1,1]) 

		
		drop data 
		rename _data data
	}
	// Song & Mare 2015
	// ereturn clear 
	// Transmission 
	ereturn scalar rp0 = p[1,1] // retrospective probability cabi=1 for parabi = 1 (at data=.5)
	ereturn scalar rp1 = p[2,1] // retrospective probability cabi=1 for parabi = 0 (at data=.5)
	ereturn scalar lnror = ln((p[2,1]/(1-p[2,1])) / (p[1,1]/(1-p[1,1])) ) // retrospective OR (at data=.5)
	
	// Fertility
	ereturn scalar z0 = 1-child[1,1]
	ereturn scalar z1 = 1-child[2,1]
	ereturn scalar f0 = f[1,1]
	ereturn scalar f1 = f[2,1]
	ereturn scalar cfr0 = cfr[1,1]
	ereturn scalar cfr1 = cfr[2,1]
	
	// Social reproduction
	ereturn scalar sr00 = `sr00'
	ereturn scalar sr01 = `sr01'
	ereturn scalar sr10 = `sr10'
	ereturn scalar sr11 = `sr11'
	
	// Joint effect
	ereturn scalar te = `te'
	ereturn scalar fe = `fe'
	ereturn scalar ieo = `ieo'
	ereturn scalar fe_rel = `fe_rel'
	
	
	// not abi
	// Social reproduction
	ereturn scalar sr000 = `sr000'
	ereturn scalar sr001 = `sr001'
	ereturn scalar sr010 = `sr010'
	ereturn scalar sr011 = `sr011'
	
	// Joint effect
	ereturn scalar te0 = `te0'
	ereturn scalar fe0 = `fe0'
	ereturn scalar ieo0 = `ieo0'
	ereturn scalar fe_rel0 = `fe_rel0'
	
	
	ereturn scalar N = `N' // case numbers
	// restore
end 


// Step-by-step calculation of measures
use 04_parent_samples, clear

// Women - west
keep if anchor == 2 
keep if part == 2 

* educational distribution of west german women 
fre parabi [aw=sw*fsw*cw] 
* educational distribution of their offsrping
fre cabi [aw=sw]


// 1. Offspring's probability of higher education (using survey weights)
logit cabi i.parabi c.F c.data [pw=sw] 
est store ret 

* predict probability adjusted for dataset (set to average dataset .5)
* setting data to .5 (average dataset) 
rename data _data 
gen data = .5 

* a) predict probability
predict pr

* b) predict counterfactual probability 
rename parabi _parabi 
gen parabi = _parabi == 0 
predict prcf 
drop parabi 
rename _parabi parabi

* 2. Offspring: Average probability by parental education
tabstat pr [aw=sw], by(parabi)
* save to matrix
preserve 
	collapse pr [aw=sw] , by(parabi)
	drop parabi
	mkmat pr , mat(p)
restore 
mat li p

* 3. Fertility G1
* Probality of having children (z = prob. of zero fertility)
* (1 - P(f=0))		
gen c = (1-z)

preserve 
	collapse c [aw=sw*fsw*cw] , by(parabi) // Survey weights * family size weights * positive fertility weights
	drop parabi
	mkmat c, mat(child)
restore 
mat li child

* Number of children given positive fertility 
* E[f | f > 0]
preserve 
	collapse F [aw=sw*fsw] , by(parabi) // Survey weights * family size weights
	drop parabi
	mkmat F , mat(f)
restore 
mat li f

* Calculate cohort fertility rate (probability of having children * conditional expectation of children)
mat cfr = (child[1,1]*f[1,1]) \ (child[2,1]*f[2,1])
mat li cfr

* 4. Educational reproduction indicators
* Conditional factual and counterfactual rate of reproduction
gen s = F*pr
gen scf = F*prcf

preserve 
	collapse s scf [aw=sw*fsw*cw] , by(parabi)
	mkmat s scf, mat(c) rownames(parabi)
restore
mat li c

* Unconditional rates (product with probability of having children)
mat r = (c[1,1]*child[1,1], c[1,2]*child[1,1]) \ ///
		(c[2,1]*child[2,1], c[2,2]*child[2,1])

mat li r

* Factual rates of reproduction		
local sr00 = r[1,1]	// lower educated women
local sr11 = r[2,1]	// higher educated women

* Counterfactual rates
local sr01 = r[1,2] // Attainment behavior of offspring from High educated women, fertility pattern of low educated women
local sr10 = r[2,2] // Attainment behavior of offspring from low educated women, fertility pattern of high educated women

		
* TOTAL (=JOINT) EFFECT 
local te =  r[2,1] - r[1,1]
di `te'

* DECOMPOSITION

* Fertility part 
local fe =  0.5*(r[2,1] - r[1,2] + r[2,2] - r[1,1])
di `fe'

* Mobility part 
local ieo =  0.5*(r[2,1] + r[1,2] - r[2,2]  - r[1,1])
di `ieo'

* %-share fertility part on total effect
local fe_rel = 0.5*(r[2,1] - r[1,2] + r[2,2] - r[1,1]) / (r[2,1] - r[1,1]) 
di `fe_rel'

drop data 
rename _data data

*****************************************
* Extension 1 - Trend model, linear trend
*****************************************
// Women - west
use 04_parent_samples, clear

recode parbrth (1930/1935=1 "30/35") ///
			   (1936/1940=2 "36/40") ///
			   (1941/1945=3 "41/45"), gen(coh)
			   

keep if anchor == 2 
keep if part == 2 

* Cohort
tabstat parabi parbrth [aw=sw*fsw*cw], by(coh) stats(mean) f(%9.2g)
* Offspring born?
tabstat brth  [aw=sw], by(coh) stats(mean) f(%9.2g)
* Offspring higher educated?
tabstat cabi  [aw=sw], by(coh) stats(mean) f(%9.2g)


gen te = .
gen fe = .
gen ieo = .
gen fe_rel = .
gen lnror = .
gen f0 = . 
gen f1 = . 
gen rp0 = .
gen rp1 = .

prospective_srr if anchor==2 & part == 2 & coh==1
replace te = e(te) if anchor==2 & part == 2 & coh==1 
replace fe = e(fe) if anchor==2 & part == 2 & coh==1 
replace ieo = e(ieo) if anchor==2 & part == 2 & coh==1 
replace fe_rel = e(fe_rel) if anchor==2 & part == 2 & coh==1 
replace lnror = e(lnror) if anchor==2 & part == 2 & coh==1 
replace f0 = e(f0) if anchor==2 & part == 2 & coh==1 
replace f1 = e(f1) if anchor==2 & part == 2 & coh==1 
replace rp0 = e(rp0) if anchor==2 & part == 2 & coh==1 
replace rp1 = e(rp1) if anchor==2 & part == 2 & coh==1 

prospective_srr if anchor==2 & part == 2 & coh==2
replace te = e(te) if anchor==2 & part == 2 & coh==2 
replace fe = e(fe) if anchor==2 & part == 2 & coh==2 
replace ieo = e(ieo) if anchor==2 & part == 2 & coh==2 
replace fe_rel = e(fe_rel) if anchor==2 & part == 2 & coh==2 
replace lnror = e(lnror) if anchor==2 & part == 2 & coh==2 
replace f0 = e(f0) if anchor==2 & part == 2 & coh==2 
replace f1 = e(f1) if anchor==2 & part == 2 & coh==2
replace rp0 = e(rp0) if anchor==2 & part == 2 & coh==2 
replace rp1 = e(rp1) if anchor==2 & part == 2 & coh==2 

prospective_srr if anchor==2 & part == 2 & coh==3
replace te = e(te) if anchor==2 & part == 2 & coh==3 
replace fe = e(fe) if anchor==2 & part == 2 & coh==3 
replace ieo = e(ieo) if anchor==2 & part == 2 & coh==3 
replace fe_rel = e(fe_rel) if anchor==2 & part == 2 & coh==3
replace lnror = e(lnror) if anchor==2 & part == 2 & coh==3
replace f0 = e(f0) if anchor==2 & part == 2 & coh==3 
replace f1 = e(f1) if anchor==2 & part == 2 & coh==3 
replace rp0 = e(rp0) if anchor==2 & part == 2 & coh==3 
replace rp1 = e(rp1) if anchor==2 & part == 2 & coh==3 

gen ieo_rel = ieo/te

gen or = exp(lnror)

gen f_diff = f1 - f0
tabstat te fe ieo fe_rel ieo_rel lnror f0 f1 f_diff, by(coh) f(%9.2f) 
tabstat rp0 rp1 or lnror, by(coh) f(%9.2f) 
stop
// Non linear development in the TE effect (dips first, increases later again), 
// IEO effect non-linear too, damping effect of fertility declines, 
// odds ratio fluctuating non-linearily

// Men - west
use 04_parent_samples, clear

recode parbrth (1930/1935=1 "30/35") ///
			   (1936/1940=2 "36/40") ///
			   (1941/1945=3 "41/45"), gen(coh)
			   

keep if anchor == 1 
keep if part == 2 

gen te = .
gen fe = .
gen ieo = .
gen fe_rel = .
gen lnror = .
gen f0 = . 
gen f1 = . 

prospective_srr if anchor==1 & part == 2 & coh==1
replace te = e(te) if anchor==1 & part == 2 & coh==1 
replace fe = e(fe) if anchor==1 & part == 2 & coh==1 
replace ieo = e(ieo) if anchor==1 & part == 2 & coh==1 
replace fe_rel = e(fe_rel) if anchor==1 & part == 2 & coh==1 
replace lnror = e(lnror) if anchor==1 & part == 2 & coh==1 
replace f0 = e(f0) if anchor==1 & part == 2 & coh==1 
replace f1 = e(f1) if anchor==1 & part == 2 & coh==1 


prospective_srr if anchor==1 & part == 2 & coh==2
replace te = e(te) if anchor==1 & part == 2 & coh==2 
replace fe = e(fe) if anchor==1 & part == 2 & coh==2 
replace ieo = e(ieo) if anchor==1 & part == 2 & coh==2 
replace fe_rel = e(fe_rel) if anchor==1 & part == 2 & coh==2 
replace lnror = e(lnror) if anchor==1 & part == 2 & coh==2 
replace f0 = e(f0) if anchor==1 & part == 2 & coh==2 
replace f1 = e(f1) if anchor==1 & part == 2 & coh==2 

prospective_srr if anchor==1 & part == 2 & coh==3
replace te = e(te) if anchor==1 & part == 2 & coh==3 
replace fe = e(fe) if anchor==1 & part == 2 & coh==3 
replace ieo = e(ieo) if anchor==1 & part == 2 & coh==3 
replace fe_rel = e(fe_rel) if anchor==1 & part == 2 & coh==3
replace lnror = e(lnror) if anchor==1 & part == 2 & coh==3
replace f0 = e(f0) if anchor==1 & part == 2 & coh==3 
replace f1 = e(f1) if anchor==1 & part == 2 & coh==3 

gen ieo_rel = ieo/te

gen f_diff = f1 - f0
tabstat te fe ieo fe_rel ieo_rel lnror f0 f1 f_diff, by(coh) f(%9.2f) 
// Totel effect remains the same, fe stays small and disappears
// Odds ratio increasing, fertility differences declining

// Women - East
use 04_parent_samples, clear

recode parbrth (1930/1935=1 "30/35") ///
			   (1936/1940=2 "36/40") ///
			   (1941/1945=3 "41/45"), gen(coh)
			   

keep if anchor == 2 
keep if part == 1

gen te = .
gen fe = .
gen ieo = .
gen fe_rel = .
gen lnror = .
gen f0 = . 
gen f1 = . 

prospective_srr if anchor==2 & part == 1 & coh==1
replace te = e(te) if anchor==2 & part == 1 & coh==1 
replace fe = e(fe) if anchor==2 & part == 1 & coh==1 
replace ieo = e(ieo) if anchor==2 & part == 1 & coh==1 
replace fe_rel = e(fe_rel) if anchor==2 & part == 1 & coh==1 
replace lnror = e(lnror) if anchor==2 & part == 1 & coh==1 
replace f0 = e(f0) if anchor==2 & part == 1 & coh==1 
replace f1 = e(f1) if anchor==2 & part == 1 & coh==1 

prospective_srr if anchor==2 & part == 1 & coh==2
replace te = e(te) if anchor==2 & part == 1 & coh==2 
replace fe = e(fe) if anchor==2 & part == 1 & coh==2 
replace ieo = e(ieo) if anchor==2 & part == 1 & coh==2 
replace fe_rel = e(fe_rel) if anchor==2 & part == 1 & coh==2 
replace lnror = e(lnror) if anchor==2 & part == 1 & coh==2 
replace f0 = e(f0) if anchor==2 & part == 1 & coh==2 
replace f1 = e(f1) if anchor==2 & part == 1 & coh==2 

prospective_srr if anchor==2 & part == 1 & coh==3
replace te = e(te) if anchor==2 & part == 1 & coh==3 
replace fe = e(fe) if anchor==2 & part == 1 & coh==3 
replace ieo = e(ieo) if anchor==2 & part == 1 & coh==3 
replace fe_rel = e(fe_rel) if anchor==2 & part == 1 & coh==3
replace lnror = e(lnror) if anchor==2 & part == 1 & coh==3
replace f0 = e(f0) if anchor==2 & part == 1 & coh==3 
replace f1 = e(f1) if anchor==2 & part == 1 & coh==3 

gen ieo_rel = ieo/te

gen f_diff = f1 - f0
tabstat te fe ieo fe_rel ieo_rel lnror f0 f1 f_diff, by(coh) f(%9.2f) 
// Total effect strongly declines, IEO effect declines, fertility remains the same (fertility differences remain largely the same)
// Odds ratio declines -> total effect declines because of declining IEO

// Men - East
use 04_parent_samples, clear

recode parbrth (1930/1935=1 "30/35") ///
			   (1936/1940=2 "36/40") ///
			   (1941/1945=3 "41/45"), gen(coh)
			   

keep if anchor == 1 
keep if part == 1 

gen te = .
gen fe = .
gen ieo = .
gen fe_rel = .
gen lnror = .
gen f0 = . 
gen f1 = . 

prospective_srr if anchor==1 & part == 1 & coh==1
replace te = e(te) if anchor==1 & part == 1 & coh==1 
replace fe = e(fe) if anchor==1 & part == 1 & coh==1 
replace ieo = e(ieo) if anchor==1 & part == 1 & coh==1 
replace fe_rel = e(fe_rel) if anchor==1 & part == 1 & coh==1 
replace lnror = e(lnror) if anchor==1 & part == 1 & coh==1 
replace f0 = e(f0) if anchor==1 & part == 1 & coh==1 
replace f1 = e(f1) if anchor==1 & part == 1 & coh==1 

prospective_srr if anchor==1 & part == 1 & coh==2
replace te = e(te) if anchor==1 & part == 1 & coh==2 
replace fe = e(fe) if anchor==1 & part == 1 & coh==2 
replace ieo = e(ieo) if anchor==1 & part == 1 & coh==2 
replace fe_rel = e(fe_rel) if anchor==1 & part == 1 & coh==2 
replace lnror = e(lnror) if anchor==1 & part == 1 & coh==2 
replace f0 = e(f0) if anchor==1 & part == 1 & coh==2 
replace f1 = e(f1) if anchor==1 & part == 1 & coh==2 

prospective_srr if anchor==1 & part == 1 & coh==3
replace te = e(te) if anchor==1 & part == 1 & coh==3 
replace fe = e(fe) if anchor==1 & part == 1 & coh==3 
replace ieo = e(ieo) if anchor==1 & part == 1 & coh==3 
replace fe_rel = e(fe_rel) if anchor==1 & part == 1 & coh==3
replace lnror = e(lnror) if anchor==1 & part == 1 & coh==3
replace f0 = e(f0) if anchor==1 & part == 1 & coh==3 
replace f1 = e(f1) if anchor==1 & part == 1 & coh==3 

gen ieo_rel = ieo/te

gen f_diff = f1 - f0
tabstat te fe ieo fe_rel ieo_rel lnror f0 f1 f_diff, by(coh) f(%9.2f) 
// Totel effect increases (but non linearly), IEO & fertility effects increase
// Odds ratio increasing, fertility differences decline


*****************************************
* Extension 2 - Assortative Mating 
*****************************************
// Women - west
use 04_parent_samples, clear

recode parbrth (1930/1935=1 "30/35") ///
			   (1936/1940=2 "36/40") ///
			   (1941/1945=3 "41/45"), gen(coh)
			   
keep if anchor == 2
keep if part == 2 

keep if !mi(par2abi)

* Parents mating patterns from offspring perspective
tab parabi par2abi [aw=sw], nofreq row

* Mating patterns from cohort perspective (no difference)
tab parabi par2abi [aw=sw*fsw*cw], nofreq row


* 1. Offsprings educational chances based on family size and parents education
* (offspring perspective)
logit cabi i.parabi c.F c.data [pw=sw] 
margins , dydx(parabi F) at(data=.5)

logit cabi i.parabi i.par2abi c.F c.data [pw=sw] 
est store ret 
margins , dydx(parabi par2abi F) at(data=.5)

* 2. Number of offspring based on mating 
* (parent perspective)
poisson F i.parabi i.par2abi c.data [pw=sw*fsw] 
margins , dydx(parabi par2abi) at(data=.5)

/*
poisson F i.parabi
margins parabi
tabstat F, by(parabi )

poisson F i.parabi [pw=sw*fsw] 
margins parabi
tabstat F [aw=sw*fsw] , by(parabi )
*/

* 3. Mothers probability of having a high educated man 
* Note: Conditional on having children (having children = being married)
* (parent perspective)
logit par2abi i.parabi c.data [pw=sw*fsw]
margins , dydx(parabi) at(data=.5)
est store mating

* 4. Cohort women's probability of marrying with children ()
gen c = 1 - z
table coh parabi, co(mean c) f(%9.2g)

* Children by ed
tabstat c [aw=sw*fsw*cw], by(parabi)
* Number by ed (conditional)
poisson F i.parabi c.data [pw=sw*fsw] 
margins parabi, at(data=.5)   
* 
logit cabi i.parabi c.data [pw=sw] 
margins parabi, at(data=.5)   
